@@ -108,8 +108,8 @@ class KinMS_plotter:
         self.beamsize = beamSize
             
         
-        matplotlib.rcParams['text.usetex'] = True
-        matplotlib.rcParams['font.family'] = 'Latin Modern Roman'
+        #matplotlib.rcParams['text.usetex'] = True
+        #matplotlib.rcParams['font.family'] = 'Latin Modern Roman'
         matplotlib.rcParams.update({'font.size': 20})
         matplotlib.rcParams['legend.fontsize'] = 17.5
         matplotlib.rcParams['axes.linewidth'] = 1.5
@@ -287,7 +287,6 @@ class KinMS_plotter:
         plt.xlabel(r'Velocity (km s$^{-1}$)')
 
         plt.tight_layout()
-        plt.show()
         if self.savepath:
             if self.savename:
                 if self.pdf:
@@ -299,7 +298,7 @@ class KinMS_plotter:
                     plt.savefig(self.savepath + '/' + 'KinMS_plots.pdf', bbox_inches='tight')
                 else:
                     plt.savefig(self.savepath + '/' + 'KinMS_plots.png', bbox_inches='tight')
-                    
+        plt.show()            
 #=============================================================================#
 #/// END OF CLASS ////////////////////////////////////////////////////////////#
 #=============================================================================#
